import { API as API$1 } from "../../../scw/api.js";
import { validatePathParam, urlParams } from "../../../helpers/marshalling.js";
import "../../../vendor/base64/index.js";
import { unmarshalListEventsResponse, unmarshalListProductsResponse } from "./marshalling.gen.js";
class API extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = ["fr-par", "nl-ams"];
  /**
   * List events. Retrieve the list of Audit Trail events for a Scaleway
   * Organization and/or Project. You must specify the `organization_id` and
   * optionally, the `project_id`.
   *
   * @param request - The request {@link ListEventsRequest}
   * @returns A Promise of ListEventsResponse
   */
  listEvents = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/audit-trail/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/events`,
      urlParams: urlParams(
        ["method_name", request.methodName],
        ["order_by", request.orderBy],
        [
          "organization_id",
          request.organizationId ?? this.client.settings.defaultOrganizationId
        ],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["page_token", request.pageToken],
        ["product_name", request.productName],
        ["project_id", request.projectId],
        ["recorded_after", request.recordedAfter],
        ["recorded_before", request.recordedBefore],
        ["resource_type", request.resourceType],
        ["status", request.status]
      )
    },
    unmarshalListEventsResponse
  );
  /**
   * Retrieve the list of Scaleway resources for which you have Audit Trail
   * events.
   *
   * @param request - The request {@link ListProductsRequest}
   * @returns A Promise of ListProductsResponse
   */
  listProducts = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/audit-trail/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/products`,
      urlParams: urlParams([
        "organization_id",
        request.organizationId ?? this.client.settings.defaultOrganizationId
      ])
    },
    unmarshalListProductsResponse
  );
}
export {
  API
};
