import { API as ParentAPI } from '../../../bridge';
import type { Zone as ScwZone, WaitForOptions } from '../../../bridge';
import type { CreateDHCPEntryRequest, CreateDHCPRequest, CreateGatewayNetworkRequest, CreateGatewayRequest, CreateIPRequest, CreatePATRuleRequest, DHCP, DHCPEntry, DeleteDHCPEntryRequest, DeleteDHCPRequest, DeleteGatewayNetworkRequest, DeleteGatewayRequest, DeleteIPRequest, DeletePATRuleRequest, EnableIPMobilityRequest, Gateway, GatewayNetwork, GetDHCPEntryRequest, GetDHCPRequest, GetGatewayNetworkRequest, GetGatewayRequest, GetIPRequest, GetPATRuleRequest, IP, ListDHCPEntriesRequest, ListDHCPEntriesResponse, ListDHCPsRequest, ListDHCPsResponse, ListGatewayNetworksRequest, ListGatewayNetworksResponse, ListGatewayTypesRequest, ListGatewayTypesResponse, ListGatewaysRequest, ListGatewaysResponse, ListIPsRequest, ListIPsResponse, ListPATRulesRequest, ListPATRulesResponse, MigrateToV2Request, PATRule, RefreshSSHKeysRequest, SetDHCPEntriesRequest, SetDHCPEntriesResponse, SetPATRulesRequest, SetPATRulesResponse, UpdateDHCPEntryRequest, UpdateDHCPRequest, UpdateGatewayNetworkRequest, UpdateGatewayRequest, UpdateIPRequest, UpdatePATRuleRequest, UpgradeGatewayRequest } from './types.gen';
/**
 * Public Gateways API.
 *
 * This API allows you to manage your Public Gateways.
 */
export declare class API extends ParentAPI {
    /** Lists the available zones of the API. */
    static readonly LOCALITIES: ScwZone[];
    protected pageOfListGateways: (request?: Readonly<ListGatewaysRequest>) => Promise<ListGatewaysResponse>;
    /**
     * List Public Gateways. List Public Gateways in a given Scaleway Organization
     * or Project. By default, results are displayed in ascending order of
     * creation date.
     *
     * @param request - The request {@link ListGatewaysRequest}
     * @returns A Promise of ListGatewaysResponse
     */
    listGateways: (request?: Readonly<ListGatewaysRequest>) => Promise<ListGatewaysResponse> & {
        all: () => Promise<Gateway[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Gateway[], void, void>;
    };
    /**
     * Get a Public Gateway. Get details of a Public Gateway, specified by its
     * gateway ID. The response object contains full details of the gateway,
     * including its **name**, **type**, **status** and more.
     *
     * @param request - The request {@link GetGatewayRequest}
     * @returns A Promise of Gateway
     */
    getGateway: (request: Readonly<GetGatewayRequest>) => Promise<Gateway>;
    /**
     * Waits for {@link Gateway} to be in a final state.
     *
     * @param request - The request {@link GetGatewayRequest}
     * @param options - The waiting options
     * @returns A Promise of Gateway
     */
    waitForGateway: (request: Readonly<GetGatewayRequest>, options?: Readonly<WaitForOptions<Gateway>>) => Promise<Gateway>;
    /**
     * Create a Public Gateway. Create a new Public Gateway in the specified
     * Scaleway Project, defining its **name**, **type** and other configuration
     * details such as whether to enable SSH bastion.
     *
     * @param request - The request {@link CreateGatewayRequest}
     * @returns A Promise of Gateway
     */
    createGateway: (request: Readonly<CreateGatewayRequest>) => Promise<Gateway>;
    /**
     * Update a Public Gateway. Update the parameters of an existing Public
     * Gateway, for example, its **name**, **tags**, **SSH bastion
     * configuration**, and **DNS servers**.
     *
     * @param request - The request {@link UpdateGatewayRequest}
     * @returns A Promise of Gateway
     */
    updateGateway: (request: Readonly<UpdateGatewayRequest>) => Promise<Gateway>;
    /**
     * Delete a Public Gateway. Delete an existing Public Gateway, specified by
     * its gateway ID. This action is irreversible.
     *
     * @param request - The request {@link DeleteGatewayRequest}
     */
    deleteGateway: (request: Readonly<DeleteGatewayRequest>) => Promise<void>;
    /**
     * Upgrade a Public Gateway to the latest version and/or to a different
     * commercial offer type. Upgrade a given Public Gateway to the newest
     * software version or to a different commercial offer type. This applies the
     * latest bugfixes and features to your Public Gateway. Note that gateway
     * service will be interrupted during the update.
     *
     * @param request - The request {@link UpgradeGatewayRequest}
     * @returns A Promise of Gateway
     */
    upgradeGateway: (request: Readonly<UpgradeGatewayRequest>) => Promise<Gateway>;
    /**
     * Upgrade a Public Gateway to IP mobility. Upgrade a Public Gateway to IP
     * mobility (move from NAT IP to routed IP). This is idempotent: repeated
     * calls after the first will return no error but have no effect.
     *
     * @param request - The request {@link EnableIPMobilityRequest}
     */
    enableIPMobility: (request: Readonly<EnableIPMobilityRequest>) => Promise<void>;
    protected pageOfListGatewayNetworks: (request?: Readonly<ListGatewayNetworksRequest>) => Promise<ListGatewayNetworksResponse>;
    /**
     * List Public Gateway connections to Private Networks. List the connections
     * between Public Gateways and Private Networks (a connection = a
     * GatewayNetwork). You can choose to filter by `gateway-id` to list all
     * Private Networks attached to the specified Public Gateway, or by
     * `private_network_id` to list all Public Gateways attached to the specified
     * Private Network. Other query parameters are also available. The result is
     * an array of GatewayNetwork objects, each giving details of the connection
     * between a given Public Gateway and a given Private Network.
     *
     * @param request - The request {@link ListGatewayNetworksRequest}
     * @returns A Promise of ListGatewayNetworksResponse
     */
    listGatewayNetworks: (request?: Readonly<ListGatewayNetworksRequest>) => Promise<ListGatewayNetworksResponse> & {
        all: () => Promise<GatewayNetwork[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<GatewayNetwork[], void, void>;
    };
    /**
     * Get a Public Gateway connection to a Private Network. Get details of a
     * given connection between a Public Gateway and a Private Network (this
     * connection = a GatewayNetwork), specified by its `gateway_network_id`. The
     * response object contains details of the connection including the IDs of the
     * Public Gateway and Private Network, the dates the connection was
     * created/updated and its configuration settings.
     *
     * @param request - The request {@link GetGatewayNetworkRequest}
     * @returns A Promise of GatewayNetwork
     */
    getGatewayNetwork: (request: Readonly<GetGatewayNetworkRequest>) => Promise<GatewayNetwork>;
    /**
     * Waits for {@link GatewayNetwork} to be in a final state.
     *
     * @param request - The request {@link GetGatewayNetworkRequest}
     * @param options - The waiting options
     * @returns A Promise of GatewayNetwork
     */
    waitForGatewayNetwork: (request: Readonly<GetGatewayNetworkRequest>, options?: Readonly<WaitForOptions<GatewayNetwork>>) => Promise<GatewayNetwork>;
    /**
     * Attach a Public Gateway to a Private Network. Attach a specific Public
     * Gateway to a specific Private Network (create a GatewayNetwork). You can
     * configure parameters for the connection including DHCP settings, whether to
     * enable masquerade (dynamic NAT), and more.
     *
     * @param request - The request {@link CreateGatewayNetworkRequest}
     * @returns A Promise of GatewayNetwork
     */
    createGatewayNetwork: (request: Readonly<CreateGatewayNetworkRequest>) => Promise<GatewayNetwork>;
    /**
     * Update a Public Gateway's connection to a Private Network. Update the
     * configuration parameters of a connection between a given Public Gateway and
     * Private Network (the connection = a GatewayNetwork). Updatable parameters
     * include DHCP settings and whether to enable traffic masquerade (dynamic
     * NAT).
     *
     * @param request - The request {@link UpdateGatewayNetworkRequest}
     * @returns A Promise of GatewayNetwork
     */
    updateGatewayNetwork: (request: Readonly<UpdateGatewayNetworkRequest>) => Promise<GatewayNetwork>;
    /**
     * Detach a Public Gateway from a Private Network. Detach a given Public
     * Gateway from a given Private Network, i.e. delete a GatewayNetwork
     * specified by a gateway_network_id.
     *
     * @param request - The request {@link DeleteGatewayNetworkRequest}
     */
    deleteGatewayNetwork: (request: Readonly<DeleteGatewayNetworkRequest>) => Promise<void>;
    protected pageOfListDHCPs: (request?: Readonly<ListDHCPsRequest>) => Promise<ListDHCPsResponse>;
    /**
     * List DHCP configurations. List DHCP configurations, optionally filtering by
     * Organization, Project, Public Gateway IP address or more. The response is
     * an array of DHCP configuration objects, each identified by a DHCP ID and
     * containing configuration settings for the assignment of IP addresses to
     * devices on a Private Network attached to a Public Gateway. Note that the
     * response does not contain the IDs of any Private Network / Public Gateway
     * the configuration is attached to. Use the `List Public Gateway connections
     * to Private Networks` method for that purpose, filtering on DHCP ID.
     *
     * @param request - The request {@link ListDHCPsRequest}
     * @returns A Promise of ListDHCPsResponse
     */
    listDHCPs: (request?: Readonly<ListDHCPsRequest>) => Promise<ListDHCPsResponse> & {
        all: () => Promise<DHCP[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<DHCP[], void, void>;
    };
    /**
     * Get a DHCP configuration. Get a DHCP configuration object, identified by
     * its DHCP ID. The response object contains configuration settings for the
     * assignment of IP addresses to devices on a Private Network attached to a
     * Public Gateway. Note that the response does not contain the IDs of any
     * Private Network / Public Gateway the configuration is attached to. Use the
     * `List Public Gateway connections to Private Networks` method for that
     * purpose, filtering on DHCP ID.
     *
     * @param request - The request {@link GetDHCPRequest}
     * @returns A Promise of DHCP
     */
    getDHCP: (request: Readonly<GetDHCPRequest>) => Promise<DHCP>;
    /**
     * Create a DHCP configuration. Create a new DHCP configuration object,
     * containing settings for the assignment of IP addresses to devices on a
     * Private Network attached to a Public Gateway. The response object includes
     * the ID of the DHCP configuration object. You can use this ID as part of a
     * call to `Create a Public Gateway connection to a Private Network` or
     * `Update a Public Gateway connection to a Private Network` to directly apply
     * this DHCP configuration.
     *
     * @param request - The request {@link CreateDHCPRequest}
     * @returns A Promise of DHCP
     */
    createDHCP: (request: Readonly<CreateDHCPRequest>) => Promise<DHCP>;
    /**
     * Update a DHCP configuration. Update a DHCP configuration object, identified
     * by its DHCP ID.
     *
     * @param request - The request {@link UpdateDHCPRequest}
     * @returns A Promise of DHCP
     */
    updateDHCP: (request: Readonly<UpdateDHCPRequest>) => Promise<DHCP>;
    /**
     * Delete a DHCP configuration. Delete a DHCP configuration object, identified
     * by its DHCP ID. Note that you cannot delete a DHCP configuration object
     * that is currently being used by a Gateway Network.
     *
     * @param request - The request {@link DeleteDHCPRequest}
     */
    deleteDHCP: (request: Readonly<DeleteDHCPRequest>) => Promise<void>;
    protected pageOfListDHCPEntries: (request?: Readonly<ListDHCPEntriesRequest>) => Promise<ListDHCPEntriesResponse>;
    /**
     * List DHCP entries. List DHCP entries, whether dynamically assigned and/or
     * statically reserved. DHCP entries can be filtered by the Gateway Network
     * they are on, their MAC address, IP address, type or hostname.
     *
     * @param request - The request {@link ListDHCPEntriesRequest}
     * @returns A Promise of ListDHCPEntriesResponse
     */
    listDHCPEntries: (request?: Readonly<ListDHCPEntriesRequest>) => Promise<ListDHCPEntriesResponse> & {
        all: () => Promise<DHCPEntry[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<DHCPEntry[], void, void>;
    };
    /**
     * Get a DHCP entry. Get a DHCP entry, specified by its DHCP entry ID.
     *
     * @param request - The request {@link GetDHCPEntryRequest}
     * @returns A Promise of DHCPEntry
     */
    getDHCPEntry: (request: Readonly<GetDHCPEntryRequest>) => Promise<DHCPEntry>;
    /**
     * Create a DHCP entry. Create a static DHCP reservation, specifying the
     * Gateway Network for the reservation, the MAC address of the target device
     * and the IP address to assign this device. The response is a DHCP entry
     * object, confirming the ID and configuration details of the static DHCP
     * reservation.
     *
     * @param request - The request {@link CreateDHCPEntryRequest}
     * @returns A Promise of DHCPEntry
     */
    createDHCPEntry: (request: Readonly<CreateDHCPEntryRequest>) => Promise<DHCPEntry>;
    /**
     * Update a DHCP entry. Update the IP address for a DHCP entry, specified by
     * its DHCP entry ID. You can update an existing DHCP entry of any type
     * (`reservation` (static), `lease` (dynamic) or `unknown`), but in manually
     * updating the IP address the entry will necessarily be of type `reservation`
     * after the update.
     *
     * @param request - The request {@link UpdateDHCPEntryRequest}
     * @returns A Promise of DHCPEntry
     */
    updateDHCPEntry: (request: Readonly<UpdateDHCPEntryRequest>) => Promise<DHCPEntry>;
    /**
     * Set all DHCP reservations on a Gateway Network. Set the list of DHCP
     * reservations attached to a Gateway Network. Reservations are identified by
     * their MAC address, and will sync the current DHCP entry list to the given
     * list, creating, updating or deleting DHCP entries accordingly.
     *
     * @param request - The request {@link SetDHCPEntriesRequest}
     * @returns A Promise of SetDHCPEntriesResponse
     */
    setDHCPEntries: (request: Readonly<SetDHCPEntriesRequest>) => Promise<SetDHCPEntriesResponse>;
    /**
     * Delete a DHCP entry. Delete a static DHCP reservation, identified by its
     * DHCP entry ID. Note that you cannot delete DHCP entries of type `lease`,
     * these are deleted automatically when their time-to-live expires.
     *
     * @param request - The request {@link DeleteDHCPEntryRequest}
     */
    deleteDHCPEntry: (request: Readonly<DeleteDHCPEntryRequest>) => Promise<void>;
    protected pageOfListPATRules: (request?: Readonly<ListPATRulesRequest>) => Promise<ListPATRulesResponse>;
    /**
     * List PAT rules. List PAT rules. You can filter by gateway ID to list all
     * PAT rules for a particular gateway, or filter for PAT rules targeting a
     * specific IP address or using a specific protocol.
     *
     * @param request - The request {@link ListPATRulesRequest}
     * @returns A Promise of ListPATRulesResponse
     */
    listPATRules: (request?: Readonly<ListPATRulesRequest>) => Promise<ListPATRulesResponse> & {
        all: () => Promise<PATRule[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<PATRule[], void, void>;
    };
    /**
     * Get a PAT rule. Get a PAT rule, specified by its PAT rule ID. The response
     * object gives full details of the PAT rule, including the Public Gateway it
     * belongs to and the configuration settings in terms of public / private
     * ports, private IP and protocol.
     *
     * @param request - The request {@link GetPATRuleRequest}
     * @returns A Promise of PATRule
     */
    getPATRule: (request: Readonly<GetPATRuleRequest>) => Promise<PATRule>;
    /**
     * Create a PAT rule. Create a new PAT rule on a specified Public Gateway,
     * defining the protocol to use, public port to listen on, and private port /
     * IP address to map to.
     *
     * @param request - The request {@link CreatePATRuleRequest}
     * @returns A Promise of PATRule
     */
    createPATRule: (request: Readonly<CreatePATRuleRequest>) => Promise<PATRule>;
    /**
     * Update a PAT rule. Update a PAT rule, specified by its PAT rule ID.
     * Configuration settings including private/public port, private IP address
     * and protocol can all be updated.
     *
     * @param request - The request {@link UpdatePATRuleRequest}
     * @returns A Promise of PATRule
     */
    updatePATRule: (request: Readonly<UpdatePATRuleRequest>) => Promise<PATRule>;
    /**
     * Set all PAT rules. Set a definitive list of PAT rules attached to a Public
     * Gateway. Each rule is identified by its public port and protocol. This will
     * sync the current PAT rule list on the gateway with the new list, creating,
     * updating or deleting PAT rules accordingly.
     *
     * @param request - The request {@link SetPATRulesRequest}
     * @returns A Promise of SetPATRulesResponse
     */
    setPATRules: (request: Readonly<SetPATRulesRequest>) => Promise<SetPATRulesResponse>;
    /**
     * Delete a PAT rule. Delete a PAT rule, identified by its PAT rule ID. This
     * action is irreversible.
     *
     * @param request - The request {@link DeletePATRuleRequest}
     */
    deletePATRule: (request: Readonly<DeletePATRuleRequest>) => Promise<void>;
    /**
     * List Public Gateway types. List the different Public Gateway commercial
     * offer types available at Scaleway. The response is an array of objects
     * describing the name and technical details of each available gateway type.
     *
     * @param request - The request {@link ListGatewayTypesRequest}
     * @returns A Promise of ListGatewayTypesResponse
     */
    listGatewayTypes: (request?: Readonly<ListGatewayTypesRequest>) => Promise<ListGatewayTypesResponse>;
    protected pageOfListIPs: (request?: Readonly<ListIPsRequest>) => Promise<ListIPsResponse>;
    /**
     * List IPs. List Public Gateway flexible IP addresses. A number of filter
     * options are available for limiting results in the response.
     *
     * @param request - The request {@link ListIPsRequest}
     * @returns A Promise of ListIPsResponse
     */
    listIPs: (request?: Readonly<ListIPsRequest>) => Promise<ListIPsResponse> & {
        all: () => Promise<IP[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<IP[], void, void>;
    };
    /**
     * Get an IP. Get details of a Public Gateway flexible IP address, identified
     * by its IP ID. The response object contains information including which (if
     * any) Public Gateway using this IP address, the reverse and various other
     * metadata.
     *
     * @param request - The request {@link GetIPRequest}
     * @returns A Promise of IP
     */
    getIP: (request: Readonly<GetIPRequest>) => Promise<IP>;
    /**
     * Reserve an IP. Create (reserve) a new flexible IP address that can be used
     * for a Public Gateway in a specified Scaleway Project.
     *
     * @param request - The request {@link CreateIPRequest}
     * @returns A Promise of IP
     */
    createIP: (request?: Readonly<CreateIPRequest>) => Promise<IP>;
    /**
     * Update an IP. Update details of an existing flexible IP address, including
     * its tags, reverse and the Public Gateway it is assigned to.
     *
     * @param request - The request {@link UpdateIPRequest}
     * @returns A Promise of IP
     */
    updateIP: (request: Readonly<UpdateIPRequest>) => Promise<IP>;
    /**
     * Delete an IP. Delete a flexible IP address from your account. This action
     * is irreversible.
     *
     * @param request - The request {@link DeleteIPRequest}
     */
    deleteIP: (request: Readonly<DeleteIPRequest>) => Promise<void>;
    /**
     * Refresh a Public Gateway's SSH keys. Refresh the SSH keys of a given Public
     * Gateway, specified by its gateway ID. This adds any new SSH keys in the
     * gateway's Scaleway Project to the gateway itself.
     *
     * @param request - The request {@link RefreshSSHKeysRequest}
     * @returns A Promise of Gateway
     */
    refreshSSHKeys: (request: Readonly<RefreshSSHKeysRequest>) => Promise<Gateway>;
    migrateToV2: (request: Readonly<MigrateToV2Request>) => Promise<void>;
}
